@@ -4,8 +4,8 @@ package Dist::Zilla::PluginBundle::Author::ETHER;
 BEGIN {
   $Dist::Zilla::PluginBundle::Author::ETHER::AUTHORITY = 'cpan:ETHER';
 }
-# git description: v0.046-4-g0aa0bed
-$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.047';
+# git description: v0.047-5-g2ef9e82
+$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.048';
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # vim: set ts=8 sw=4 tw=78 et :
 
@@ -20,7 +20,7 @@ use Moose::Util::TypeConstraints;
 use List::MoreUtils qw(any first_index);
 use namespace::autoclean;
 
-sub mvp_multivalue_args { qw(installer) }
+sub mvp_multivalue_args { qw(installer copy_file_from_release) }
 
 # Note: no support yet for depending on a specific version of the plugin --
 # but [PromptIfStale] generally makes that unnecessary
@@ -56,6 +56,18 @@ has airplane => (
     },
 );
 
+has copy_file_from_release => (
+    isa => 'ArrayRef[Str]',
+    lazy => 1,
+    default => sub {
+        exists $_[0]->payload->{copy_file_from_release}
+            ? $_[0]->payload->{copy_file_from_release}
+            : [ qw(README.md LICENSE CONTRIBUTING) ];
+    },
+    traits => ['Array'],
+    handles => { copy_files_from_release => 'elements' },
+);
+
 has _requested_version => (
     is => 'ro', isa => 'Str',
     lazy => 1,
@@ -106,7 +118,7 @@ sub configure
         [ 'Git::NextVersion'    => { version_regexp => '^v([\d._]+)(-TRIAL)?$' } ],
 
         # BeforeBuild
-        [ 'PromptIfStale' => 'build' => { phase => 'build', module => [ blessed($self) ] } ],
+        [ 'PromptIfStale' => 'build' => { phase => 'build', module => [ $self->meta->name ] } ],
         [ 'PromptIfStale' => 'release' => { phase => 'release', check_all_plugins => 1, check_all_prereqs => 1 } ],
 
         # ExecFiles, ShareDir
@@ -117,7 +129,7 @@ sub configure
         [ 'FileFinder::ByName' => Examples => { dir => 'examples' } ],
 
         # Gather Files
-        [ 'Git::GatherDir'      => { ':version' => '2.016', exclude_filename => [ qw(README.md LICENSE CONTRIBUTING) ] } ],
+        [ 'Git::GatherDir'      => { ':version' => '2.016', exclude_filename => [ $self->copy_files_from_release ] } ],
         qw(MetaYAML MetaJSON License Readme Manifest),
         [ 'GenerateFile::ShareDir' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING' } ],
 
@@ -146,10 +158,6 @@ sub configure
         'Test::Portability',
 
 
-        # Prune Files
-        'PruneCruft',
-        'ManifestSkip',
-
         # Munge Files
         'Git::Describe',
         [ PkgVersion            => { ':version' => '5.010', die_on_existing_version => 1, die_on_line_insertion => 1 } ],
@@ -181,7 +189,7 @@ sub configure
         [ 'Prereqs' => installer_requirements => {
                 '-phase' => 'develop', '-relationship' => 'requires',
                 'Dist::Zilla' => Dist::Zilla->VERSION,
-                blessed($self) => $self->_requested_version,
+                $self->meta->name => $self->_requested_version,
 
                 # this is useless for "dzil authordeps", as by the time this
                 # runs, we're already trying to load the installer plugin --
@@ -193,7 +201,7 @@ sub configure
             } ],
         [ 'Prereqs' => pluginbundle_version => {
                 '-phase' => 'develop', '-relationship' => 'recommends',
-                blessed($self) => $self->VERSION,
+                $self->meta->name => $self->VERSION,
             } ],
 
         # Test Runner
@@ -209,21 +217,21 @@ sub configure
 
 
         # Before Release
-        [ 'Git::Check'          => 'initial check' => { allow_dirty => [] } ],
+        [ 'Git::Check'          => 'initial check' => { allow_dirty => ['foo'] } ],
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
         [ 'Git::Remote::Check'  => { branch => 'master', remote_branch => 'master' } ],
         'CheckPrereqsIndexed',
         'TestRelease',
-        [ 'Git::Check'          => 'after tests' => { allow_dirty => [] } ],
+        [ 'Git::Check'          => 'after tests' => { allow_dirty => ['foo'] } ],
         # (ConfirmRelease)
 
         # Releaser
         'UploadToCPAN',
 
         # After Release
-        [ 'CopyFilesFromRelease' => { filename => [ qw(README.md LICENSE CONTRIBUTING) ] } ],
-        [ 'Git::Commit'         => { add_files_in => [''], allow_dirty => [ qw(Changes README.md LICENSE CONTRIBUTING) ], commit_msg => '%N-%v%t%n%n%c' } ],
+        [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
+        [ 'Git::Commit'         => { add_files_in => [''], allow_dirty => [ 'Changes', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? (
             [ 'GitHub::Update' => { metacpan => 1 } ],
@@ -286,7 +294,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -374,11 +382,6 @@ following F<dist.ini> (following the preamble):
     [Test::Portability]
 
 
-    ;;; Prune Files
-    [PruneCruft]
-    [ManifestSkip]
-
-
     ;;; Munge Files
     [Git::Describe]
     [PkgVersion]
@@ -484,9 +487,9 @@ following F<dist.ini> (following the preamble):
 
     ;;; AfterRelease
     [CopyFilesFromRelease]
-    copy = README.md
-    copy = LICENSE
-    copy = CONTRIBUTING
+    filename = README.md
+    filename = LICENSE
+    filename = CONTRIBUTING
 
     [Git::Commit]
     add_files_in =
@@ -611,6 +614,12 @@ A boolean option, that when set, removes the use of all plugins that use the
 network (generally for comparing metadata against PAUSE, and querying the
 remote git server), as well as blocking the use of the C<release> command.
 
+=head2 copy_file_from_release
+
+A file, to be present in the build, which is copied back to the source
+repository at release time and committed to git. Can be repeated more than
+once. Defaults to: F<README.md>, F<LICENSE>, F<CONTRIBUTING>.
+
 =head2 other customizations
 
 This bundle makes use of L<Dist::Zilla::Role::PluginBundle::PluginRemover> and
